==> narayana-jts-idlj-5.9.8.Final-sources.jar: com/arjuna/ats/jta/logging/jtaLogger.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2006, Red Hat Middleware LLC, and individual contributors 
 * as indicated by the @author tags. 
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors. 
 * This copyrighted material is made available to anyone wishing to use,
 * modify, copy, or redistribute it subject to the terms and conditions
 * of the GNU Lesser General Public License, v. 2.1.
 * This program is distributed in the hope that it will be useful, but WITHOUT A 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License,
 * v.2.1 along with this distribution; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
 * MA  02110-1301, USA.
 * 
 * (C) 2005-2006,
 * @author JBoss Inc.
 */
/*
 * Copyright (C) 2001, 2002,
 *
 * Hewlett-Packard Arjuna Labs,
 * Newcastle upon Tyne,
 * Tyne and Wear,
 * UK.
 *
 * $Id: jtaLogger.java 2342 2006-03-30 13:06:17Z  $
 */

package com.arjuna.ats.jta.logging;

import org.jboss.logging.Logger;

import java.lang.reflect.InvocationHandler;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.lang.reflect.Proxy;

public class jtaLogger implements InvocationHandler
{
    public static final Logger logger = Logger.getLogger("com.arjuna.ats.jta");
    public static final jtaI18NLogger i18NLogger = (jtaI18NLogger) Proxy.newProxyInstance(
            jtaI18NLogger.class.getClassLoader(),
            new Class[] { jtaI18NLogger.class },
            new jtaLogger(Logger.getMessageLogger(jtaI18NLogger.class, "com.arjuna.ats.jta")));

    private jtaI18NLogger jtaI18NLoggerImpl;
    private static boolean recoveryProblems;

    private jtaLogger() {
    }

    private jtaLogger(jtaI18NLogger logger) {
        jtaI18NLoggerImpl = logger;
    }

    public static boolean isRecoveryProblems() {
        return recoveryProblems;
    }

    public static void setRecoveryProblems(boolean recoveryProblems) {
        jtaLogger.recoveryProblems = recoveryProblems;
    }

    @Override
    public Object invoke(Object proxy, Method method, Object[] args) throws Throwable {
        try {
            if (method.getName().startsWith("warn_recovery")) {
                recoveryProblems = true;
            }

            return method.invoke(jtaI18NLoggerImpl, args);
        } catch (InvocationTargetException e) {
            throw e.getCause() != null ? e.getCause() : e;
        }
    }
}

==> narayana-jts-idlj-5.10.5.Final-sources.jar: com/arjuna/ats/jta/logging/jtaLogger.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2006, Red Hat Middleware LLC, and individual contributors 
 * as indicated by the @author tags. 
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors. 
 * This copyrighted material is made available to anyone wishing to use,
 * modify, copy, or redistribute it subject to the terms and conditions
 * of the GNU Lesser General Public License, v. 2.1.
 * This program is distributed in the hope that it will be useful, but WITHOUT A 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License,
 * v.2.1 along with this distribution; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
 * MA  02110-1301, USA.
 * 
 * (C) 2005-2006,
 * @author JBoss Inc.
 */
/*
 * Copyright (C) 2001, 2002,
 *
 * Hewlett-Packard Arjuna Labs,
 * Newcastle upon Tyne,
 * Tyne and Wear,
 * UK.
 *
 * $Id: jtaLogger.java 2342 2006-03-30 13:06:17Z  $
 */

package com.arjuna.ats.jta.logging;

import org.jboss.logging.Logger;

public class jtaLogger
{
    public static final Logger logger = Logger.getLogger("com.arjuna.ats.jta");

    public static final jtaI18NLogger i18NLogger = Logger.getMessageLogger(jtaI18NLogger.class, "com.arjuna.ats.jta");

    private jtaI18NLogger jtaI18NLoggerImpl;

    private jtaLogger() {
    }

    private jtaLogger(jtaI18NLogger logger) {
        jtaI18NLoggerImpl = logger;
    }
}
